#! /usr/bin/env python
"""This module implements the URL specification defined in RFC 1738

"""
import string


class URLException(Exception):
    pass
